pitchtools.NumberedPitchClassObject
===================================

.. inheritance-diagram:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__eq__

    Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__hash__

    Inherited from :py:class:`pitchtools.PitchClassObject <abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__ne__

    Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchClassObject.NumberedPitchClassObject.NumberedPitchClassObject.__repr__

    Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`
